You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@accumulo.apache.org by ct...@apache.org on 2016/06/03 02:21:00 UTC

[01/19] accumulo git commit: ACCUMULO-4165 Made RFileWriter start default LG automatically

Repository: accumulo
Updated Branches:
  refs/heads/1.6 63a8a5d7e -> beb69cdfc
  refs/heads/1.7 d33b2a09d -> 0eab0ecff
  refs/heads/1.8 24465d675 -> 68576ad59
  refs/heads/master c77648377 -> 35de95264


ACCUMULO-4165 Made RFileWriter start default LG automatically


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/24465d67
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/24465d67
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/24465d67

Branch: refs/heads/master
Commit: 24465d675501440685aa026a032211afa837db64
Parents: e67317c
Author: Keith Turner <ke...@deenlo.com>
Authored: Thu Jun 2 16:57:48 2016 -0400
Committer: Keith Turner <ke...@deenlo.com>
Committed: Thu Jun 2 16:57:48 2016 -0400

----------------------------------------------------------------------
 .../accumulo/core/client/rfile/RFileWriter.java | 29 +++++++++---------
 .../accumulo/core/client/rfile/RFileTest.java   | 31 ++++----------------
 2 files changed, 20 insertions(+), 40 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/24465d67/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java b/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
index 3029592..4993810 100644
--- a/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
@@ -104,7 +104,6 @@ public class RFileTest {
     String testFile = createTmpTestFile();
 
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(FileSystem.getLocal(new Configuration())).build()) {
-      writer.startDefaultLocalityGroup();
       writer.append(testData.entrySet());
       // TODO ensure compressors are returned
     }
@@ -198,7 +197,6 @@ public class RFileTest {
     RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).withTableProperties(props).build();
 
     SortedMap<Key,Value> testData1 = createTestData(10, 10, 10);
-    writer.startDefaultLocalityGroup();
     writer.append(testData1.entrySet());
     writer.close();
 
@@ -307,7 +305,6 @@ public class RFileTest {
     Value v2 = new Value("c".getBytes());
     Value v3 = new Value("t".getBytes());
 
-    writer.startDefaultLocalityGroup();
     writer.append(k1, v1);
     writer.append(k2, v2);
     writer.append(k3, v3);
@@ -345,7 +342,6 @@ public class RFileTest {
     Value v1 = new Value("p".getBytes());
     Value v2 = new Value("".getBytes());
 
-    writer.startDefaultLocalityGroup();
     writer.append(k2, v2);
     writer.append(k1, v1);
     writer.close();
@@ -409,7 +405,6 @@ public class RFileTest {
     Value v1 = new Value("p".getBytes());
     Value v2 = new Value("q".getBytes());
 
-    writer.startDefaultLocalityGroup();
     writer.append(k2, v2);
     writer.append(k1, v1);
     writer.close();
@@ -435,7 +430,6 @@ public class RFileTest {
     SamplerConfiguration sc = new SamplerConfiguration(RowSampler.class).setOptions(ImmutableMap.of("hasher", "murmur3_32", "modulus", "19"));
 
     RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).withSampler(sc).build();
-    writer.startDefaultLocalityGroup();
     writer.append(testData1.entrySet());
     writer.close();
 
@@ -473,7 +467,6 @@ public class RFileTest {
 
     String testFile2 = createTmpTestFile();
     RFileWriter writer = RFile.newWriter().to(testFile2).build();
-    writer.startDefaultLocalityGroup();
     writer.append(scanner);
     writer.close();
     scanner.close();
@@ -517,7 +510,6 @@ public class RFileTest {
     LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
     String testFile = createTmpTestFile();
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      writer.startDefaultLocalityGroup();
       writer.append(k2, v2);
       writer.append(k1, v1);
     }
@@ -539,7 +531,6 @@ public class RFileTest {
     LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
     String testFile = createTmpTestFile();
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      writer.startDefaultLocalityGroup();
       writer.append(data);
     }
   }
@@ -570,32 +561,21 @@ public class RFileTest {
   }
 
   @Test(expected = IllegalStateException.class)
-  public void testNoLocalityGroupStarted() throws Exception {
-    LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
-    String testFile = createTmpTestFile();
-    try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      Key k1 = new Key("r1", "f1", "q1");
-      writer.append(k1, new Value("".getBytes()));
-    }
-  }
-
-  @Test(expected = IllegalStateException.class)
-  public void testNoLocalityGroupStartedIterable() throws Exception {
+  public void testDoubleStart() throws Exception {
     LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
     String testFile = createTmpTestFile();
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      Key k1 = new Key("r1", "f1", "q1");
-      Entry<Key,Value> entry = new AbstractMap.SimpleEntry<>(k1, new Value("".getBytes()));
-      writer.append(Collections.singletonList(entry));
+      writer.startDefaultLocalityGroup();
+      writer.startDefaultLocalityGroup();
     }
   }
 
   @Test(expected = IllegalStateException.class)
-  public void testDoubleStart() throws Exception {
+  public void testAppendStartDefault() throws Exception {
     LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
     String testFile = createTmpTestFile();
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      writer.startDefaultLocalityGroup();
+      writer.append(new Key("r1", "f1", "q1"), new Value("1".getBytes()));
       writer.startDefaultLocalityGroup();
     }
   }
@@ -605,7 +585,6 @@ public class RFileTest {
     LocalFileSystem localFs = FileSystem.getLocal(new Configuration());
     String testFile = createTmpTestFile();
     try (RFileWriter writer = RFile.newWriter().to(testFile).withFileSystem(localFs).build()) {
-      writer.startDefaultLocalityGroup();
       Key k1 = new Key("r1", "f1", "q1");
       writer.append(k1, new Value("".getBytes()));
       writer.startNewLocalityGroup("lg1", "fam1");


[13/19] accumulo git commit: Merge branch '1.7' into 1.8

Posted by ct...@apache.org.
Merge branch '1.7' into 1.8

This merges the change for ACCUMULO-4322, but not for ACCUMULO-4321,
which would revert ACCUMULO-3804.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/a749ddb1
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/a749ddb1
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/a749ddb1

Branch: refs/heads/master
Commit: a749ddb17233606b000a01d0a5e928a24b993dc5
Parents: 24465d6 0eab0ec
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 19:56:28 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 19:56:28 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/a749ddb1/pom.xml
----------------------------------------------------------------------
diff --cc pom.xml
index f783731,20484ce..1093dba
--- a/pom.xml
+++ b/pom.xml
@@@ -116,15 -115,11 +116,15 @@@
      <url>https://builds.apache.org/view/A-D/view/Accumulo/</url>
    </ciManagement>
    <properties>
 +    <!-- Interface used to separate tests with JUnit category -->
 +    <accumulo.performanceTests>org.apache.accumulo.test.PerformanceTest</accumulo.performanceTests>
      <!-- used for filtering the java source with the current version -->
      <accumulo.release.version>${project.version}</accumulo.release.version>
-     <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+     <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
      <!-- bouncycastle version for test dependencies -->
      <bouncycastle.version>1.50</bouncycastle.version>
 +    <!-- Curator version -->
 +    <curator.version>2.7.1</curator.version>
      <!-- relative path for Eclipse format; should override in child modules if necessary -->
      <eclipseFormatterStyle>${project.parent.basedir}/contrib/Eclipse-Accumulo-Codestyle.xml</eclipseFormatterStyle>
      <!-- extra release args for testing -->


[02/19] accumulo git commit: ACCUMULO-4321 Only seal jars on release

Posted by ct...@apache.org.
ACCUMULO-4321 Only seal jars on release

Skip jar sealing under normal builds by default, so integration tests
don't generate sealing violation errors. Seal jars in the release
profile.

This is a quick fix. The long-term fix is to ensure any integration
and/or performance tests are in distinct packages so they can be run
even with released jars.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/14959351
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/14959351
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/14959351

Branch: refs/heads/1.6
Commit: 149593517d822e06b103c6db9b49eb2707b053ce
Parents: 63a8a5d
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:42:54 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:42:54 2016 -0400

----------------------------------------------------------------------
 pom.xml | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/14959351/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index c1494d7..04df37d 100644
--- a/pom.xml
+++ b/pom.xml
@@ -139,6 +139,7 @@
     <powermock.version>1.6.4</powermock.version>
     <!-- surefire/failsafe plugin option -->
     <reuseForks>false</reuseForks>
+    <sealJars>false</sealJars>
     <!-- overwritten in hadoop profiles -->
     <slf4j.version>1.7.5</slf4j.version>
     <sourceReleaseAssemblyDescriptor>source-release-tar</sourceReleaseAssemblyDescriptor>
@@ -613,7 +614,7 @@
           <configuration>
             <archive>
               <manifestEntries>
-                <Sealed>true</Sealed>
+                <Sealed>${sealJars}</Sealed>
                 <Implementation-Build>${mvngit.commit.id}</Implementation-Build>
               </manifestEntries>
             </archive>
@@ -1163,6 +1164,7 @@
         <!-- some properties to make the release build a bit faster -->
         <checkstyle.skip>true</checkstyle.skip>
         <findbugs.skip>true</findbugs.skip>
+        <sealJars>true</sealJars>
         <skipITs>true</skipITs>
         <skipTests>true</skipTests>
       </properties>


[03/19] accumulo git commit: ACCUMULO-4321 Only seal jars on release

Posted by ct...@apache.org.
ACCUMULO-4321 Only seal jars on release

Skip jar sealing under normal builds by default, so integration tests
don't generate sealing violation errors. Seal jars in the release
profile.

This is a quick fix. The long-term fix is to ensure any integration
and/or performance tests are in distinct packages so they can be run
even with released jars.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/14959351
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/14959351
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/14959351

Branch: refs/heads/1.8
Commit: 149593517d822e06b103c6db9b49eb2707b053ce
Parents: 63a8a5d
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:42:54 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:42:54 2016 -0400

----------------------------------------------------------------------
 pom.xml | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/14959351/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index c1494d7..04df37d 100644
--- a/pom.xml
+++ b/pom.xml
@@ -139,6 +139,7 @@
     <powermock.version>1.6.4</powermock.version>
     <!-- surefire/failsafe plugin option -->
     <reuseForks>false</reuseForks>
+    <sealJars>false</sealJars>
     <!-- overwritten in hadoop profiles -->
     <slf4j.version>1.7.5</slf4j.version>
     <sourceReleaseAssemblyDescriptor>source-release-tar</sourceReleaseAssemblyDescriptor>
@@ -613,7 +614,7 @@
           <configuration>
             <archive>
               <manifestEntries>
-                <Sealed>true</Sealed>
+                <Sealed>${sealJars}</Sealed>
                 <Implementation-Build>${mvngit.commit.id}</Implementation-Build>
               </manifestEntries>
             </archive>
@@ -1163,6 +1164,7 @@
         <!-- some properties to make the release build a bit faster -->
         <checkstyle.skip>true</checkstyle.skip>
         <findbugs.skip>true</findbugs.skip>
+        <sealJars>true</sealJars>
         <skipITs>true</skipITs>
         <skipTests>true</skipTests>
       </properties>


[07/19] accumulo git commit: ACCUMULO-4322 Use newer posix mode for tarballs

Posted by ct...@apache.org.
ACCUMULO-4322 Use newer posix mode for tarballs

Make maven-assembly-plugin use posix mode for building any tar artifacts
for maximum cross-platform compatibility.

Some older versions of GNU tar (and perhaps other versions of tar) do
not support this mode, but Accumulo probably wouldn't run on older
systems which ship those old versions of tar anyway.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/beb69cdf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/beb69cdf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/beb69cdf

Branch: refs/heads/1.7
Commit: beb69cdfcdef1512e7c6d8adb3a7f15be0640147
Parents: 1495935
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:46:23 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:46:23 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/beb69cdf/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 04df37d..45ca0ba 100644
--- a/pom.xml
+++ b/pom.xml
@@ -116,7 +116,7 @@
   <properties>
     <!-- used for filtering the java source with the current version -->
     <accumulo.release.version>${project.version}</accumulo.release.version>
-    <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+    <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
     <!-- bouncycastle version for test dependencies -->
     <bouncycastle.version>1.50</bouncycastle.version>
     <!-- relative path for Eclipse format; should override in child modules if necessary -->


[12/19] accumulo git commit: Merge branch '1.6' into 1.7

Posted by ct...@apache.org.
Merge branch '1.6' into 1.7


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/0eab0ecf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/0eab0ecf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/0eab0ecf

Branch: refs/heads/master
Commit: 0eab0ecff07fcd79fc7050907f83d6ff57b47ce2
Parents: d33b2a0 beb69cd
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 19:44:50 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 19:44:50 2016 -0400

----------------------------------------------------------------------
 pom.xml | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/0eab0ecf/pom.xml
----------------------------------------------------------------------


[14/19] accumulo git commit: Merge branch '1.7' into 1.8

Posted by ct...@apache.org.
Merge branch '1.7' into 1.8

This merges the change for ACCUMULO-4322, but not for ACCUMULO-4321,
which would revert ACCUMULO-3804.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/a749ddb1
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/a749ddb1
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/a749ddb1

Branch: refs/heads/1.8
Commit: a749ddb17233606b000a01d0a5e928a24b993dc5
Parents: 24465d6 0eab0ec
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 19:56:28 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 19:56:28 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/a749ddb1/pom.xml
----------------------------------------------------------------------
diff --cc pom.xml
index f783731,20484ce..1093dba
--- a/pom.xml
+++ b/pom.xml
@@@ -116,15 -115,11 +116,15 @@@
      <url>https://builds.apache.org/view/A-D/view/Accumulo/</url>
    </ciManagement>
    <properties>
 +    <!-- Interface used to separate tests with JUnit category -->
 +    <accumulo.performanceTests>org.apache.accumulo.test.PerformanceTest</accumulo.performanceTests>
      <!-- used for filtering the java source with the current version -->
      <accumulo.release.version>${project.version}</accumulo.release.version>
-     <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+     <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
      <!-- bouncycastle version for test dependencies -->
      <bouncycastle.version>1.50</bouncycastle.version>
 +    <!-- Curator version -->
 +    <curator.version>2.7.1</curator.version>
      <!-- relative path for Eclipse format; should override in child modules if necessary -->
      <eclipseFormatterStyle>${project.parent.basedir}/contrib/Eclipse-Accumulo-Codestyle.xml</eclipseFormatterStyle>
      <!-- extra release args for testing -->


[19/19] accumulo git commit: Merge branch '1.8'

Posted by ct...@apache.org.
Merge branch '1.8'


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/35de9526
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/35de9526
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/35de9526

Branch: refs/heads/master
Commit: 35de9526477fa147fe184aa805e72bedb75c37cd
Parents: c776483 68576ad
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 21:58:55 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 21:58:55 2016 -0400

----------------------------------------------------------------------
 .../accumulo/core/client/rfile/RFileWriter.java | 32 +++++++++-----------
 .../core/util/format/DefaultFormatter.java      |  4 +--
 .../accumulo/core/client/rfile/RFileTest.java   | 31 +++----------------
 pom.xml                                         |  2 +-
 4 files changed, 23 insertions(+), 46 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/35de9526/pom.xml
----------------------------------------------------------------------


[08/19] accumulo git commit: ACCUMULO-4322 Use newer posix mode for tarballs

Posted by ct...@apache.org.
ACCUMULO-4322 Use newer posix mode for tarballs

Make maven-assembly-plugin use posix mode for building any tar artifacts
for maximum cross-platform compatibility.

Some older versions of GNU tar (and perhaps other versions of tar) do
not support this mode, but Accumulo probably wouldn't run on older
systems which ship those old versions of tar anyway.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/beb69cdf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/beb69cdf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/beb69cdf

Branch: refs/heads/1.8
Commit: beb69cdfcdef1512e7c6d8adb3a7f15be0640147
Parents: 1495935
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:46:23 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:46:23 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/beb69cdf/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 04df37d..45ca0ba 100644
--- a/pom.xml
+++ b/pom.xml
@@ -116,7 +116,7 @@
   <properties>
     <!-- used for filtering the java source with the current version -->
     <accumulo.release.version>${project.version}</accumulo.release.version>
-    <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+    <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
     <!-- bouncycastle version for test dependencies -->
     <bouncycastle.version>1.50</bouncycastle.version>
     <!-- relative path for Eclipse format; should override in child modules if necessary -->


[17/19] accumulo git commit: ACCUMULO-2493 (javadoc) fix warning

Posted by ct...@apache.org.
ACCUMULO-2493 (javadoc) fix warning

Fixes a warning on some versions of javadoc which cannot find a linked
method without explicit full parameter types.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/68576ad5
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/68576ad5
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/68576ad5

Branch: refs/heads/1.8
Commit: 68576ad59facdf4d24a32a47d3961c332360438a
Parents: b517cc0
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 21:57:15 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 21:57:15 2016 -0400

----------------------------------------------------------------------
 .../org/apache/accumulo/core/util/format/DefaultFormatter.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/68576ad5/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java b/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
index 5517b78..b5df632 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
@@ -65,8 +65,8 @@ public class DefaultFormatter implements Formatter {
   }
 
   /**
-   * if showTimestamps, will use {@link org.apache.accumulo.core.util.format.FormatterConfig.DefaultDateFormat}. Preferably, use
-   * {@link #formatEntry(Entry, FormatterConfig)}
+   * if showTimestamps, will use {@link FormatterConfig.DefaultDateFormat}.<br>
+   * Preferably, use {@link DefaultFormatter#formatEntry(java.util.Map.Entry, org.apache.accumulo.core.util.format.FormatterConfig)}
    */
   public static String formatEntry(Entry<Key,Value> entry, boolean showTimestamps) {
     DateFormat timestampFormat = null;


[16/19] accumulo git commit: ACCUMULO-4165 (javadoc) Remove empty paragraph

Posted by ct...@apache.org.
ACCUMULO-4165 (javadoc) Remove empty paragraph


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/b517cc0a
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/b517cc0a
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/b517cc0a

Branch: refs/heads/1.8
Commit: b517cc0a01a748e597c59774c30ce213319d127a
Parents: a749ddb
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 20:38:49 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 20:38:49 2016 -0400

----------------------------------------------------------------------
 .../java/org/apache/accumulo/core/client/rfile/RFileWriter.java   | 3 ---
 1 file changed, 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/b517cc0a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
index 13da017..0c4d682 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
@@ -50,12 +50,9 @@ import com.google.common.base.Preconditions;
  * <li>The default locality group must be started last.</li>
  * </ul>
  *
- *
  * <p>
  * Below is an example of using RFileWriter
  *
- * <p>
- *
  * <pre>
  * {@code
  *    Iterable<Entry<Key, Value>> localityGroup1Data = ...


[18/19] accumulo git commit: ACCUMULO-2493 (javadoc) fix warning

Posted by ct...@apache.org.
ACCUMULO-2493 (javadoc) fix warning

Fixes a warning on some versions of javadoc which cannot find a linked
method without explicit full parameter types.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/68576ad5
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/68576ad5
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/68576ad5

Branch: refs/heads/master
Commit: 68576ad59facdf4d24a32a47d3961c332360438a
Parents: b517cc0
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 21:57:15 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 21:57:15 2016 -0400

----------------------------------------------------------------------
 .../org/apache/accumulo/core/util/format/DefaultFormatter.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/68576ad5/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java b/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
index 5517b78..b5df632 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/format/DefaultFormatter.java
@@ -65,8 +65,8 @@ public class DefaultFormatter implements Formatter {
   }
 
   /**
-   * if showTimestamps, will use {@link org.apache.accumulo.core.util.format.FormatterConfig.DefaultDateFormat}. Preferably, use
-   * {@link #formatEntry(Entry, FormatterConfig)}
+   * if showTimestamps, will use {@link FormatterConfig.DefaultDateFormat}.<br>
+   * Preferably, use {@link DefaultFormatter#formatEntry(java.util.Map.Entry, org.apache.accumulo.core.util.format.FormatterConfig)}
    */
   public static String formatEntry(Entry<Key,Value> entry, boolean showTimestamps) {
     DateFormat timestampFormat = null;


[09/19] accumulo git commit: ACCUMULO-4322 Use newer posix mode for tarballs

Posted by ct...@apache.org.
ACCUMULO-4322 Use newer posix mode for tarballs

Make maven-assembly-plugin use posix mode for building any tar artifacts
for maximum cross-platform compatibility.

Some older versions of GNU tar (and perhaps other versions of tar) do
not support this mode, but Accumulo probably wouldn't run on older
systems which ship those old versions of tar anyway.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/beb69cdf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/beb69cdf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/beb69cdf

Branch: refs/heads/master
Commit: beb69cdfcdef1512e7c6d8adb3a7f15be0640147
Parents: 1495935
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:46:23 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:46:23 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/beb69cdf/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 04df37d..45ca0ba 100644
--- a/pom.xml
+++ b/pom.xml
@@ -116,7 +116,7 @@
   <properties>
     <!-- used for filtering the java source with the current version -->
     <accumulo.release.version>${project.version}</accumulo.release.version>
-    <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+    <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
     <!-- bouncycastle version for test dependencies -->
     <bouncycastle.version>1.50</bouncycastle.version>
     <!-- relative path for Eclipse format; should override in child modules if necessary -->


[10/19] accumulo git commit: Merge branch '1.6' into 1.7

Posted by ct...@apache.org.
Merge branch '1.6' into 1.7


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/0eab0ecf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/0eab0ecf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/0eab0ecf

Branch: refs/heads/1.7
Commit: 0eab0ecff07fcd79fc7050907f83d6ff57b47ce2
Parents: d33b2a0 beb69cd
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 19:44:50 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 19:44:50 2016 -0400

----------------------------------------------------------------------
 pom.xml | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/0eab0ecf/pom.xml
----------------------------------------------------------------------


[05/19] accumulo git commit: ACCUMULO-4321 Only seal jars on release

Posted by ct...@apache.org.
ACCUMULO-4321 Only seal jars on release

Skip jar sealing under normal builds by default, so integration tests
don't generate sealing violation errors. Seal jars in the release
profile.

This is a quick fix. The long-term fix is to ensure any integration
and/or performance tests are in distinct packages so they can be run
even with released jars.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/14959351
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/14959351
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/14959351

Branch: refs/heads/master
Commit: 149593517d822e06b103c6db9b49eb2707b053ce
Parents: 63a8a5d
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:42:54 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:42:54 2016 -0400

----------------------------------------------------------------------
 pom.xml | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/14959351/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index c1494d7..04df37d 100644
--- a/pom.xml
+++ b/pom.xml
@@ -139,6 +139,7 @@
     <powermock.version>1.6.4</powermock.version>
     <!-- surefire/failsafe plugin option -->
     <reuseForks>false</reuseForks>
+    <sealJars>false</sealJars>
     <!-- overwritten in hadoop profiles -->
     <slf4j.version>1.7.5</slf4j.version>
     <sourceReleaseAssemblyDescriptor>source-release-tar</sourceReleaseAssemblyDescriptor>
@@ -613,7 +614,7 @@
           <configuration>
             <archive>
               <manifestEntries>
-                <Sealed>true</Sealed>
+                <Sealed>${sealJars}</Sealed>
                 <Implementation-Build>${mvngit.commit.id}</Implementation-Build>
               </manifestEntries>
             </archive>
@@ -1163,6 +1164,7 @@
         <!-- some properties to make the release build a bit faster -->
         <checkstyle.skip>true</checkstyle.skip>
         <findbugs.skip>true</findbugs.skip>
+        <sealJars>true</sealJars>
         <skipITs>true</skipITs>
         <skipTests>true</skipTests>
       </properties>


[15/19] accumulo git commit: ACCUMULO-4165 (javadoc) Remove empty paragraph

Posted by ct...@apache.org.
ACCUMULO-4165 (javadoc) Remove empty paragraph


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/b517cc0a
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/b517cc0a
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/b517cc0a

Branch: refs/heads/master
Commit: b517cc0a01a748e597c59774c30ce213319d127a
Parents: a749ddb
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 20:38:49 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 20:38:49 2016 -0400

----------------------------------------------------------------------
 .../java/org/apache/accumulo/core/client/rfile/RFileWriter.java   | 3 ---
 1 file changed, 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/b517cc0a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
index 13da017..0c4d682 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
@@ -50,12 +50,9 @@ import com.google.common.base.Preconditions;
  * <li>The default locality group must be started last.</li>
  * </ul>
  *
- *
  * <p>
  * Below is an example of using RFileWriter
  *
- * <p>
- *
  * <pre>
  * {@code
  *    Iterable<Entry<Key, Value>> localityGroup1Data = ...


[06/19] accumulo git commit: ACCUMULO-4322 Use newer posix mode for tarballs

Posted by ct...@apache.org.
ACCUMULO-4322 Use newer posix mode for tarballs

Make maven-assembly-plugin use posix mode for building any tar artifacts
for maximum cross-platform compatibility.

Some older versions of GNU tar (and perhaps other versions of tar) do
not support this mode, but Accumulo probably wouldn't run on older
systems which ship those old versions of tar anyway.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/beb69cdf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/beb69cdf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/beb69cdf

Branch: refs/heads/1.6
Commit: beb69cdfcdef1512e7c6d8adb3a7f15be0640147
Parents: 1495935
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:46:23 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:46:23 2016 -0400

----------------------------------------------------------------------
 pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/beb69cdf/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 04df37d..45ca0ba 100644
--- a/pom.xml
+++ b/pom.xml
@@ -116,7 +116,7 @@
   <properties>
     <!-- used for filtering the java source with the current version -->
     <accumulo.release.version>${project.version}</accumulo.release.version>
-    <assembly.tarLongFileMode>gnu</assembly.tarLongFileMode>
+    <assembly.tarLongFileMode>posix</assembly.tarLongFileMode>
     <!-- bouncycastle version for test dependencies -->
     <bouncycastle.version>1.50</bouncycastle.version>
     <!-- relative path for Eclipse format; should override in child modules if necessary -->


[04/19] accumulo git commit: ACCUMULO-4321 Only seal jars on release

Posted by ct...@apache.org.
ACCUMULO-4321 Only seal jars on release

Skip jar sealing under normal builds by default, so integration tests
don't generate sealing violation errors. Seal jars in the release
profile.

This is a quick fix. The long-term fix is to ensure any integration
and/or performance tests are in distinct packages so they can be run
even with released jars.


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/14959351
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/14959351
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/14959351

Branch: refs/heads/1.7
Commit: 149593517d822e06b103c6db9b49eb2707b053ce
Parents: 63a8a5d
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 18:42:54 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 18:42:54 2016 -0400

----------------------------------------------------------------------
 pom.xml | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/14959351/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index c1494d7..04df37d 100644
--- a/pom.xml
+++ b/pom.xml
@@ -139,6 +139,7 @@
     <powermock.version>1.6.4</powermock.version>
     <!-- surefire/failsafe plugin option -->
     <reuseForks>false</reuseForks>
+    <sealJars>false</sealJars>
     <!-- overwritten in hadoop profiles -->
     <slf4j.version>1.7.5</slf4j.version>
     <sourceReleaseAssemblyDescriptor>source-release-tar</sourceReleaseAssemblyDescriptor>
@@ -613,7 +614,7 @@
           <configuration>
             <archive>
               <manifestEntries>
-                <Sealed>true</Sealed>
+                <Sealed>${sealJars}</Sealed>
                 <Implementation-Build>${mvngit.commit.id}</Implementation-Build>
               </manifestEntries>
             </archive>
@@ -1163,6 +1164,7 @@
         <!-- some properties to make the release build a bit faster -->
         <checkstyle.skip>true</checkstyle.skip>
         <findbugs.skip>true</findbugs.skip>
+        <sealJars>true</sealJars>
         <skipITs>true</skipITs>
         <skipTests>true</skipTests>
       </properties>


[11/19] accumulo git commit: Merge branch '1.6' into 1.7

Posted by ct...@apache.org.
Merge branch '1.6' into 1.7


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/0eab0ecf
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/0eab0ecf
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/0eab0ecf

Branch: refs/heads/1.8
Commit: 0eab0ecff07fcd79fc7050907f83d6ff57b47ce2
Parents: d33b2a0 beb69cd
Author: Christopher Tubbs <ct...@apache.org>
Authored: Thu Jun 2 19:44:50 2016 -0400
Committer: Christopher Tubbs <ct...@apache.org>
Committed: Thu Jun 2 19:44:50 2016 -0400

----------------------------------------------------------------------
 pom.xml | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/0eab0ecf/pom.xml
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
index aad4908..13da017 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/rfile/RFileWriter.java
@@ -42,10 +42,9 @@ import com.google.common.base.Preconditions;
  * {@link TableOperations#importDirectory(String, String, String, boolean)}
  *
  * <p>
- * A RFileWriter has the following constraints. Violating these contraints will result in runtime exceptions.
+ * A RFileWriter has the following constraints. Violating these constraints will result in runtime exceptions.
  *
  * <ul>
- * <li>Before appending any keys, a locality group must be started by calling one of the startNewLocalityGroup functions or startDefaultLocalityGroup.</li>
  * <li>Keys must be appended in sorted order within a locality group.</li>
  * <li>Locality groups must have a mutually exclusive set of column families.</li>
  * <li>The default locality group must be started last.</li>
@@ -128,14 +127,17 @@ public class RFileWriter implements AutoCloseable {
   }
 
   /**
-   * See have doc for {@link #startNewLocalityGroup(String, List)}
+   * See javadoc for {@link #startNewLocalityGroup(String, List)}
+   *
+   * @throws IllegalStateException
+   *           When default locality group already started.
    */
   public void startNewLocalityGroup(String name, byte[]... families) throws IOException {
     startNewLocalityGroup(name, Arrays.asList(families));
   }
 
   /**
-   * See have doc for {@link #startNewLocalityGroup(String, List)}.
+   * See javadoc for {@link #startNewLocalityGroup(String, List)}.
    *
    * @param families
    *          will be encoded using UTF-8
@@ -152,7 +154,7 @@ public class RFileWriter implements AutoCloseable {
   }
 
   /**
-   * See have doc for {@link #startNewLocalityGroup(String, List)}.
+   * See javadoc for {@link #startNewLocalityGroup(String, List)}.
    *
    * @param families
    *          will be encoded using UTF-8
@@ -170,7 +172,7 @@ public class RFileWriter implements AutoCloseable {
 
   /**
    * A locality group in which the column families do not need to specified. The locality group must be started after all other locality groups. Can not append
-   * column families that were in a previous locality group.
+   * column families that were in a previous locality group. If no locality groups were started, then the first append will start the default locality group.
    *
    * @throws IllegalStateException
    *           When default locality group already started.
@@ -184,7 +186,8 @@ public class RFileWriter implements AutoCloseable {
   }
 
   /**
    * Append the key and value to the last locality group that was started.
    *
    * @param key
    *          This key must be greater than or equal to the last key appended. For non-default locality groups, the keys column family must be one of the column
@@ -195,11 +198,11 @@ public class RFileWriter implements AutoCloseable {
    * @throws IllegalArgumentException
    *           This is thrown when data is appended out of order OR when the key contains a invalid visibility OR when a column family is not valid for a
    *           locality group.
-   * @throws IllegalStateException
-   *           Thrown when no locality group was started.
    */
   public void append(Key key, Value val) throws IOException {
-    Preconditions.checkState(startedLG, "No locality group was started");
+    if (!startedLG) {
+      startDefaultLocalityGroup();
+    }
     Boolean wasChecked = (Boolean) validVisibilities.get(key.getColumnVisibilityData());
     if (wasChecked == null) {
       byte[] cv = key.getColumnVisibilityData().toArray();
@@ -214,16 +217,14 @@ public class RFileWriter implements AutoCloseable {
    *
    * @param keyValues
    *          The keys must be in sorted order. The first key returned by the iterable must be greater than or equal to the last key appended. For non-default
    *          locality groups, the keys column family must be one of the column families specified when calling startNewLocalityGroup(). Must be non-null.
    *
    * @throws IllegalArgumentException
    *           This is thrown when data is appended out of order OR when the key contains a invalid visibility OR when a column family is not valid for a
    *           locality group.
-   * @throws IllegalStateException
-   *           When no locality group was started.
    */
   public void append(Iterable<Entry<Key,Value>> keyValues) throws IOException {
-    Preconditions.checkState(startedLG, "No locality group was started");
     for (Entry<Key,Value> entry : keyValues) {
       append(entry.getKey(), entry.getValue());
     }

http://git-wip-us.apache.org/repos/asf/accumulo/blob/24465d67/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
----------------------------------------------------------------------
@@ -184,7 +186,8 @@ public class RFileWriter implements AutoCloseable {
 
   /**
-   * Append the key and value to the last locality group that was started.
+   * Append the key and value to the last locality group that was started. If no locality group was started, then the default group will automatically be
+   * started.
    *
    * @param key
@@ -214,16 +217,14 @@ public class RFileWriter implements AutoCloseable {
    * @param keyValues
    *          The keys must be in sorted order. The first key returned by the iterable must be greater than or equal to the last key appended. For non-default
-   *          locality groups, the keys column family must be one of the column families specified when calling startNewLocalityGroup(). Must be non-null.
+   *          locality groups, the keys column family must be one of the column families specified when calling startNewLocalityGroup(). Must be non-null. If no
+   *          locality group was started, then the default group will automatically be started.
    *
    * @throws IllegalArgumentException